{% extends "base.html" %}
{% block title %}{{ post.title }} - {% endblock %}
{% block content %}
<article class="post post__full">
    <h2 class="title">
        {% if post.link %}
            <a href="{{ post.link }}">→ {{ post.title }}</a> • <a href="/blog/{{ post.date.year }}/{{ post.date.month }}/{{ post.date.day }}/{{ post.name}}/#cut">∞</a>
        {% else %}
            {{ post.title }}
        {% endif %}   
    </h2>
    <div class="micropress-post entry-content">
        {{ post.content }}
        <a name="cut"></a>
        {{ post.description }}
        <div class="entry-content__bottom">  
            <a href="/blog/{{ post.date.year }}/{{ post.date.month }}/{{ post.date.day }}/{{ post.name}}/#cut">∞</a><br>
            <time datetime="{{ post.date.get_iso() }}" data-updated="true">{{ post.date.get_full() }}</time>
            <div class="tags">
                {% include "tags.html" %}
            </div>
        </div>         
    </div>
	<div id="disqus_thread"></div>
	<script type="text/javascript">
	    /* * * CONFIGURATION VARIABLES: EDIT BEFORE PASTING INTO YOUR WEBPAGE * * */
	    var disqus_shortname = '{{ author }}'; // required: replace example with your forum shortname

	    /* * * DON'T EDIT BELOW THIS LINE * * */
	    (function() {
	        var dsq = document.createElement('script'); dsq.type = 'text/javascript'; dsq.async = true;
	        dsq.src = 'http://' + disqus_shortname + '.disqus.com/embed.js';
	        (document.getElementsByTagName('head')[0] || document.getElementsByTagName('body')[0]).appendChild(dsq);
	    })();
	</script>
	<noscript>Please enable JavaScript to view the <a href="http://disqus.com/?ref_noscript">comments powered by Disqus.</a></noscript>
	<a href="http://disqus.com" class="dsq-brlink">comments powered by <span class="logo-disqus">Disqus</span></a>
</article>
<script src="/javascripts/jquery.fancybox.pack.js"></script>
<script type="text/javascript">
    (function($){
        $('.fancybox').fancybox();
    })(jQuery);
</script>        
{% endblock %}