<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <title>{% block title %}{% endblock %}{{ name }}</title>
    <meta name="author" content="{{ author }}">
    <meta name="description" content="{% block description %}{% endblock %}">
    <meta name="viewport" content="width=device-width, initial-scale=0.9, maximum-scale=1">
    {% block meta %}{% endblock %}
    <link href="/atom.xml" rel="alternate" title="" type="application/atom+xml">
    <link href="/favicon.png" rel="shortcut icon">
    <link href="/stylesheets/screen.css" media="screen, projection" rel="stylesheet" type="text/css">
    <!--[if lt IE 9]><script src="//html5shiv.googlecode.com/svn/trunk/html5.js"></script><![endif]-->
    <script src="//ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.min.js"></script>
	<script src="/javascripts/preview.js"></script>
    <link rel="stylesheet" href="http://yandex.st/highlightjs/7.3/styles/github.min.css">
    <script src="http://yandex.st/highlightjs/7.3/highlight.min.js"></script>
    <script>
        hljs.tabReplace = '    ';
        hljs.initHighlightingOnLoad();
    </script>
</head>
<body>
    <header id="header" class="inner">
        <h1><a href="/">{{ name }}</a></h1>
        <nav id="main-nav">
            <ul class="main">
                <li><a href="/blog/archives/">Архив</a></li>
                {% for page in pages %}
                <li><a href="/{{ page.name }}/">{{ page.title }}</a></li>
                {% endfor %}
            </ul>
        </nav>
        <nav id="mobile-nav">
            <div class="alignleft menu">
                <a class="button">Меню</a>
                <div class="container">
                    <ul class="main">
                        <li><a href="/blog/archives/">Архив</a></li>
                        {% for page in pages %}
                        <li><a href="/{{ page.name }}/">{{ page.title }}</a></li>
                        {% endfor %}
                    </ul>
                </div>
            </div>
            <div class="alignright search">
                <a class="button"></a>
                <div class="container">
                    <form method="get">
                        <input type="text" name="q" results="0">
                        <input type="hidden" name="q">
                    </form>
                </div>
            </div>
        </nav>
        <nav id="sub-nav" class="alignright">
            <div class="social">
                <a class="rss" href="/atom.xml" title="RSS">RSS</a>
            </div>
        </nav>
    </header>
    <div id="content" class="inner">
        {% block content %}{% endblock %}
    </div>
    <div class="micropress-container" style="display: none"></div>
    <footer id="footer" class="inner">&copy; {{ author }}, {{ date }}</footer>
    <script src="/javascripts/slash.js"></script>
</body>
</html>
